.xprez-module__content {
	.ck-content {
		max-width: 700px;
		margin: 0 30px;
		padding-top: .5rem;
		padding-bottom: .5rem;
	}

	.ck-placeholder {
		font-style: italic;
		margin-left: 0;
	}

	.ck.ck-editor__editable_inline>:first-child {
		margin-top: 0;
	}

	.ck.ck-editor__editable_inline>:last-child {
		margin-bottom: 0;
	}
}
