{% block content %}
    <div class="{% block css_class %}xprez-module xprez-module-margin-bottom-{{ content.margin_bottom }} {{ content.css_class|default:"" }} {% block css_class_extra %}{% endblock %}{% endblock %}">
        {% block content_in %}
        {% endblock %}
    </div>
{% endblock %}

{% block js %} {% endblock %}