//
// FRONTEND
// 

	// breakpoints
	$break-l: 1024px !default;
	$break-m: 650px !default;
	$break-s: 430px !default;

	// typo breakpoints
	$typo-break-l: $break-l !default;
	$typo-break-m: $break-m !default;
	$typo-break-s: $break-s !default;

	// spacing
	$l-space: 88px !default;
	$m-space: 28px !default;
	$s-space: 12px !default;
	$xs-space: 7px !default;

	$mobile-edge-space: $s-space !default;

	// layout widths
	$full-width: 100% !default;
	$l-width: 1400px !default;
	$m-width: 1260px !default;
	$s-width: 700px !default;

	// grid
	// $g: 16px !default; - TODO check, if this is possible with older projects
	$g: 1rem !default;

	// modules spacing
	$module-spacing-base: $g !default;

	$sans:  "acumin-pro", Helvetica ,Arial , sans-serif !default;
	$serif:  Georgia, serif !default;
	$condensed: "trumpgothicpro", "Arial", sans-serif !default;
	$heading-font-family: $sans !default;
	$body-font-family: $sans !default;

	//colors
	$white: #FFF !default;
	$black: #1E1E21 !default;
	$gray: #78747D !default;
	$light-gray: #D2D2D3 !default;
	$super-light-gray: #F6F6F6 !default;
	$txt-gray: #37383C !default;
	$txt-box-gray: #CAD1DB !default;

	$b-gray-1: #F8F9FA !default;
	$b-gray-2: #F6F7F8 !default;
	$b-gray-3: #E9ECEF !default;
	$b-gray-4: #DEE2E6 !default;
	$b-gray-5: #CED4DA !default;
	$b-gray-6: #ADB5BD !default;
	$b-gray-7: #868E96 !default;
	$b-gray-8: #343A40 !default;

	$b-purple: #7950F2 !default;
	$b-blue: #359CBA !default;
	$b-blue-high: #1D5EC7 !default;
	$b-red: #D10420 !default;

	// base settings
	$base-box-bg: $super-light-gray !default;
	$base-text-color:  $black !default;
	$base-font-size: 1rem !default;
	$base-lh: 1.5 !default;
	$base-border-radius: 0 !default;
	$basefont: $base-font-size;

	//
	// TEXT MODULE
	//

	$use-xprez-text-styles: true !default;

	$xprez-base-color: $base-text-color !default;
	$text-module-base-lh: $base-lh !default;

	$text-module-heading-letter-spacing: -0.04em !default;
	$text-module-heading-weight: 700 !default;
	$text-module-heading-emphasis-weight: 700 !default;
	$text-module-heading-emphasis-color: $gray !default;

	$text-module-column-width: $s-width !default;
	$text-module-p-size: $base-font-size !default;
	$text-module-p-lh: $text-module-base-lh !default;
	$text-module-p-mt: null !default;
	$text-module-p-mb: 1em !default;

	$text-module-h2-fluid-size: 2.2rem !default;
	$text-module-h2-lh: 1.25 !default;
	$text-module-h2-mt: 1em !default;
	$text-module-h2-mb: 0.5em !default;
	$text-module-h2-weight: $text-module-heading-weight !default;
	$text-module-h2-color: null !default;

	$text-module-h3-fluid-size: 1rem !default;
	$text-module-h3-lh: 1.25 !default;
	$text-module-h3-mt: 1.5em !default;
	$text-module-h3-mb: 0.5em !default;
	$text-module-h3-weight: $text-module-heading-weight !default;
	$text-module-h3-color: null !default;

	$text-module-h4-size: 1.125rem !default;
	$text-module-h4-lh: $text-module-base-lh !default;
	$text-module-h4-mt: 1em !default;
	$text-module-h4-mb: 0 !default;
	$text-module-h4-weight: $text-module-heading-weight !default;
	$text-module-h4-color: null !default;

	$text-module-small-size: 0.875em !default;

	$text-module-list-mt: 1rem !default;
	$text-module-list-mb: 1rem !default;
	$text-module-list-h: 0rem !default;
	$text-module-list-ps: 3rem !default;
	$text-module-list-row-size: $text-module-p-size !default;
	$text-module-list-row-lh: $text-module-p-lh !default;
	$text-module-list-row-mt: null !default;
	$text-module-list-row-mb: 0.5em !default;

	$use-xprez-blockquote-box-style: true !default;
	$text-module-blockquote-fluid-size: 1rem !default;
	$text-module-blockquote-lh: 1.5 !default;
	$text-module-blockquote-mt: 3rem !default;
	$text-module-blockquote-mb: 3rem !default;
	$text-module-blockquote-ms: 0 !default;
	$text-module-blockquote-me: 0 !default;
	$text-module-blockquote-box-dash-bg: $light-gray !default;

	$text-module-media-mt: 2rem !default;
	$text-module-media-mb: 2rem !default;

	//
	// BOXED TEXT
	//

	$text-module-boxed-bg: $super-light-gray !default;
	$text-module-boxed-radius: $base-border-radius !default;

	//
	// GRID BOXES
	//

	// sizes should be em because of scaling and are independent on $use-xprez-text-styles setting
	$gridbox-base-size: $base-font-size !default;

	$gridbox-h2-size: 3.125em !default;
	$gridbox-h3-size: 2em !default;
	$gridbox-base-relative-size: 1em !default;
	$gridbox-button-size: 0.875em !default;

	$gridbox-m-scale: 1 !default;
	$gridbox-s-scale: 0.875 !default;
	$gridbox-xs-scale: 0.8 !default;

	$gridbox-use-small-buttons: true !default;

	$gridbox-margin-s: 16px !default;
	$gridbox-margin-m: $gridbox-margin-s * 2 !default;
	$gridbox-margin-l: $gridbox-margin-s * 4 !default;
	$gridbox-padding: $gridbox-margin-s * 2 !default;

	$gridbox-background: $b-gray-3 !default;
	$gridbox-border: 1px solid $b-gray-4 !default;
	$gridbox-border-radius: $base-border-radius !default;


	//
	// BUTTON
	//

	$use-xprez-button-styles: true !default;

	$button-size: $base-font-size * 0.875 !default;
	$button-font-family: $sans !default;
	$button-border-radius: $base-border-radius * .5 !default;
	$button-border: none !default;
	$button-text-shadow: none !default;
	$button-text-decoration: none !default;
	$button-text-transform: none !default;
	$button-letter-spacing: 0.05em !default;
	$button-box-shadow: none !default;
	$button-padding-v: 1.25em;
	$button-padding-h: 1.75em;

	$button-primary-bg: $txt-gray !default;
	$button-primary-text-color: $white !default;
	$button-primary-hover-bg: lighten($txt-gray, 10%) !default;
	$button-primary-hover-text-color: $white !default;
	$button-secondary-bg: $light-gray !default;
	$button-secondary-text-color: $txt-gray !default;
	$button-secondary-hover-bg: darken($light-gray,10%) !default;
	$button-secondary-hover-text-color: $txt-gray !default;

	//
	// DOWNLOAD
	//

	$download-box-bg: $base-box-bg !default;
	$download-cell-padding-v: 0.5rem !default;

	$download-button-size: $base-font-size * 0.875 !default;
	$download-button-padding-v: 0.5rem !default;
	$download-button-bg: null !default;
	$download-button-hover-bg: null !default;

	$download-name-size: $base-font-size !default;
	$download-name-lh: null !default;
	$download-name-weight: normal !default;

	//
	// NUMBERS
	//

	$numbers-digit-size: 3.5rem !default;
	$numbers-digit-weight: 600 !default;

	$numbers-suffix-weight: 500 !default;
	$numbers-suffix-size: $numbers-digit-size * 1 !default;
	$numbers-suffix-ml: 0.15em !default;
	$numbers-suffix-opacity: 0.8 !default;

	$numbers-description-size: 0.75rem !default;
	$numbers-description-lh: 1.25 !default;
	$numbers-description-weight: bold !default;
	$numbers-description-text-transform: uppercase !default;
	$numbers-description-style: none !default;
	$numbers-description-opacity: 0.5 !default;

	$numbers-stroke-bg: $light-gray !default;

	//
	// QUOTE
	//

	$quote-width: $s-width !default;
	$quote-2-cols-width: $m-width !default;

	$quote-box-bg: $base-box-bg !default;
	$quote-box-padding-v:  4rem !default;
	$quote-head-title-mb:  2rem !default;
	$quote-avatar-width:  150px !default;
	$quote-avatar-name-size:  $base-font-size !default;

	$quote-title-fluid-size: $text-module-h3-fluid-size !default;
	$quote-title-lh: $text-module-h3-lh !default;
	$quote-title-mt: 0 !default;
	$quote-title-mb: 0.5em !default;
	$quote-title-weight: $text-module-heading-weight !default;

	$quote-text-font-family: $serif !default;
	$quote-text-font-style: italic !default;
	$quote-text-size: 1.125rem !default;
	$quote-text-lh: null !default;
	$quote-text-mt: 0 !default;
	$quote-text-mb: 1em !default;

	//
	// VIDEO
	//

	$video-button-color: white !default;
	$video-button-size: 130px !default;
	$video-ratio-height: 56.25% !default;

	//
	// TEXT-IMAGE
	//

	$textimage-module-width: $m-width !default;
	$textimage-breakpoint: 800px !default;
	$textimage-text-column-spacing: $m-space * 4 !default;
	$textimage-image-column-spacing: $m-space * 2 !default;
	$textimage-text-max-width: 600px !default;


//
// BACKEND
// 

	$min-width: 400px !default;
	$g-b: 16px !default;
	$basefont-b: 14px !default;
	$font-b: Arial, Helvetica, sans-serif !default;

