// content blocks relations

@mixin relation($o, $l, $m, $s, $dir: bottom) { // grid multiples
	margin-#{$dir}: $module-spacing-base * $o;

	@media only screen and (max-width: $typo-break-l) {
       margin-#{$dir} : $module-spacing-base * $l;
    }

    @media only screen and (max-width: $typo-break-m) {
       margin-#{$dir}: $module-spacing-base * $m;
    }

    @media only screen and (max-width: $typo-break-s) {
       margin-#{$dir}: $module-spacing-base * $s;
    }
}

.xprez-module-margin-bottom-0 {
	@include relation(0, 0, 0, 0);
}

.xprez-module-margin-bottom-1 {
	@include relation(2, 1.75, 1.5, 1);
}

.xprez-module-margin-bottom-2 {
	@include relation(5, 4, 3, 2);
}

.xprez-module-margin-bottom-3 {
	@include relation(7.5, 6, 4.5, 3);
}

.xprez-module-margin-bottom-4 {
	@include relation(10, 8, 6, 4);
}



.xprez-module {
	//& + .xprez-module {
	//	@include relation(5,4,3,2);
	//}
	//
	//& + .xprez-gallery {
	//	@include relation(5,3,2,1.5);
	//}
	//
	//& + .xprez-gallery.text-width {
	//	@include relation(3,1.5,1.5,1.5);
	//}

	//&:last-child {
	//	margin-bottom: $g*5;
	//	@media only screen and (max-width: $typo-break-s) {
	//       margin-bottom: $g*2;
	//    }
	//}

	//&.xprez-quote-boxed:last-child,
	//&.xprez-photo-connect-true.full-width:last-child {
	//	margin-bottom: 0;
	//}
}
.xprez-gallery {
	//& + .xprez-module {
	//	@include relation(5,4,3,2);
	//}
	//
	//& + & {
	//	margin-top: 0;
	//}
}
.xprez-grid-boxes {
	//& + & {
	//	margin-top: 0;
	//}
}


